==> sagemaker-0.9.0-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/EndpointConfigResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.4 (build e80a889)", date = "2018-09-11T09:55:15.526Z")
public interface EndpointConfigResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    java.lang.Object getProductionVariants();
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    void setProductionVariants(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    java.lang.Object getEndpointConfigName();
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    void setEndpointConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    java.lang.Object getKmsKeyId();
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    void setKmsKeyId(final java.lang.String value);
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    void setKmsKeyId(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link EndpointConfigResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EndpointConfigResourceProps}
     */
    final class Builder {
        private java.lang.Object _productionVariants;
        @javax.annotation.Nullable
        private java.lang.Object _endpointConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _kmsKeyId;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of ProductionVariants
         * @param value ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @return {@code this}
         */
        public Builder withProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
            this._productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
            return this;
        }
        /**
         * Sets the value of ProductionVariants
         * @param value ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @return {@code this}
         */
        public Builder withProductionVariants(final java.util.List<java.lang.Object> value) {
            this._productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this._endpointConfigName = value;
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointConfigName = value;
            return this;
        }
        /**
         * Sets the value of KmsKeyId
         * @param value ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @return {@code this}
         */
        public Builder withKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
            this._kmsKeyId = value;
            return this;
        }
        /**
         * Sets the value of KmsKeyId
         * @param value ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @return {@code this}
         */
        public Builder withKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._kmsKeyId = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::EndpointConfig.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::EndpointConfig.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointConfigResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EndpointConfigResourceProps build() {
            return new EndpointConfigResourceProps() {
                private java.lang.Object $productionVariants = java.util.Objects.requireNonNull(_productionVariants, "productionVariants is required");
                @javax.annotation.Nullable
                private java.lang.Object $endpointConfigName = _endpointConfigName;
                @javax.annotation.Nullable
                private java.lang.Object $kmsKeyId = _kmsKeyId;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getProductionVariants() {
                    return this.$productionVariants;
                }

                @Override
                public void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
                }

                @Override
                public void setProductionVariants(final java.util.List<java.lang.Object> value) {
                    this.$productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
                }

                @Override
                public java.lang.Object getEndpointConfigName() {
                    return this.$endpointConfigName;
                }

                @Override
                public void setEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$endpointConfigName = value;
                }

                @Override
                public void setEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointConfigName = value;
                }

                @Override
                public java.lang.Object getKmsKeyId() {
                    return this.$kmsKeyId;
                }

                @Override
                public void setKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
                    this.$kmsKeyId = value;
                }

                @Override
                public void setKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$kmsKeyId = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which for javascript object literal which adhere to this interface.
     */
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.EndpointConfigResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public java.lang.Object getProductionVariants() {
            return this.jsiiGet("productionVariants", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("productionVariants", java.util.Objects.requireNonNull(value, "productionVariants is required"));
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public void setProductionVariants(final java.util.List<java.lang.Object> value) {
            this.jsiiSet("productionVariants", java.util.Objects.requireNonNull(value, "productionVariants is required"));
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getEndpointConfigName() {
            return this.jsiiGet("endpointConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("endpointConfigName", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointConfigName", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getKmsKeyId() {
            return this.jsiiGet("kmsKeyId", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        public void setKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("kmsKeyId", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        public void setKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("kmsKeyId", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> sagemaker-0.9.1-sources.jar: software/amazon/awscdk/services/sagemaker/cloudformation/EndpointConfigResourceProps.java <==
package software.amazon.awscdk.services.sagemaker.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.5 (build 845cc48)", date = "2018-09-14T09:15:29.321Z")
public interface EndpointConfigResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    java.lang.Object getProductionVariants();
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
     */
    void setProductionVariants(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    java.lang.Object getEndpointConfigName();
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    void setEndpointConfigName(final java.lang.String value);
    /**
     * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
     */
    void setEndpointConfigName(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    java.lang.Object getKmsKeyId();
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    void setKmsKeyId(final java.lang.String value);
    /**
     * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
     */
    void setKmsKeyId(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::SageMaker::EndpointConfig.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link EndpointConfigResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link EndpointConfigResourceProps}
     */
    final class Builder {
        private java.lang.Object _productionVariants;
        @javax.annotation.Nullable
        private java.lang.Object _endpointConfigName;
        @javax.annotation.Nullable
        private java.lang.Object _kmsKeyId;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of ProductionVariants
         * @param value ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @return {@code this}
         */
        public Builder withProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
            this._productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
            return this;
        }
        /**
         * Sets the value of ProductionVariants
         * @param value ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @return {@code this}
         */
        public Builder withProductionVariants(final java.util.List<java.lang.Object> value) {
            this._productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this._endpointConfigName = value;
            return this;
        }
        /**
         * Sets the value of EndpointConfigName
         * @param value ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @return {@code this}
         */
        public Builder withEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._endpointConfigName = value;
            return this;
        }
        /**
         * Sets the value of KmsKeyId
         * @param value ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @return {@code this}
         */
        public Builder withKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
            this._kmsKeyId = value;
            return this;
        }
        /**
         * Sets the value of KmsKeyId
         * @param value ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @return {@code this}
         */
        public Builder withKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._kmsKeyId = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::EndpointConfig.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::SageMaker::EndpointConfig.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EndpointConfigResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public EndpointConfigResourceProps build() {
            return new EndpointConfigResourceProps() {
                private java.lang.Object $productionVariants = java.util.Objects.requireNonNull(_productionVariants, "productionVariants is required");
                @javax.annotation.Nullable
                private java.lang.Object $endpointConfigName = _endpointConfigName;
                @javax.annotation.Nullable
                private java.lang.Object $kmsKeyId = _kmsKeyId;
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getProductionVariants() {
                    return this.$productionVariants;
                }

                @Override
                public void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
                }

                @Override
                public void setProductionVariants(final java.util.List<java.lang.Object> value) {
                    this.$productionVariants = java.util.Objects.requireNonNull(value, "productionVariants is required");
                }

                @Override
                public java.lang.Object getEndpointConfigName() {
                    return this.$endpointConfigName;
                }

                @Override
                public void setEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
                    this.$endpointConfigName = value;
                }

                @Override
                public void setEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$endpointConfigName = value;
                }

                @Override
                public java.lang.Object getKmsKeyId() {
                    return this.$kmsKeyId;
                }

                @Override
                public void setKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
                    this.$kmsKeyId = value;
                }

                @Override
                public void setKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$kmsKeyId = value;
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.sagemaker.cloudformation.EndpointConfigResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public java.lang.Object getProductionVariants() {
            return this.jsiiGet("productionVariants", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public void setProductionVariants(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("productionVariants", java.util.Objects.requireNonNull(value, "productionVariants is required"));
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.ProductionVariants``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-productionvariants
         */
        @Override
        public void setProductionVariants(final java.util.List<java.lang.Object> value) {
            this.jsiiSet("productionVariants", java.util.Objects.requireNonNull(value, "productionVariants is required"));
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getEndpointConfigName() {
            return this.jsiiGet("endpointConfigName", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("endpointConfigName", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.EndpointConfigName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-endpointconfigname
         */
        @Override
        public void setEndpointConfigName(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("endpointConfigName", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getKmsKeyId() {
            return this.jsiiGet("kmsKeyId", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        public void setKmsKeyId(@javax.annotation.Nullable final java.lang.String value) {
            this.jsiiSet("kmsKeyId", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.KmsKeyId``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-kmskeyid
         */
        @Override
        public void setKmsKeyId(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("kmsKeyId", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::SageMaker::EndpointConfig.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sagemaker-endpointconfig.html#cfn-sagemaker-endpointconfig-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}
